Index: /nutchez-0.2/src/shell/client_install
===================================================================
--- /nutchez-0.2/src/shell/client_install	(revision 223)
+++ /nutchez-0.2/src/shell/client_install	(revision 224)
@@ -18,18 +18,25 @@
 Linux_Version="";
 Nutchuser_Passwd="xxxxxxxxxx";
-Work_Path="./"
-Work_Path_J=0
 
+Work_Path=`dirname "$0"`
+
+if [ -f $Work_Path/client_install_func.sh ];then
+  Work_Path=`cd "$Work_Path"; pwd`
+elif [ -f $Work_Path/bin/client_install_func.sh ];then
+  Work_Path=`cd "$Work_Path/bin"; pwd`;
+else
+  echo "Import the installation libraries of client Error!!!"
+  exit 1;
+fi
+
+#Work_Path="./"
+#Work_Path_J=0
 # Work Path Setup
-echo $0 | grep '/' || Work_Path_J=1
-if [ "$Work_Path_J" == "0"  ]; then
-    Work_Path=$(echo $0 | sed 's/client_install//')
-fi
-# Source functions
-#if [ ! -f $Work_Path/client_install_func.sh ];then
-#  scp 
+#echo $0 | grep '/' || Work_Path_J=1
+#if [ "$Work_Path_J" == "0"  ]; then
+#    Work_Path=$(echo $0 | sed 's/client_install//')
 #fi
+
 source $Work_Path/client_install_func.sh;
-  
 
 # Language Choice
Index: /nutchez-0.2/src/shell/install
===================================================================
--- /nutchez-0.2/src/shell/install	(revision 223)
+++ /nutchez-0.2/src/shell/install	(revision 224)
@@ -4,18 +4,10 @@
 # 變數宣告
 
-Work_Path="./"
-Work_Path_J=0
+Work_Path=`dirname "$0"`
 
-# Work Path setup
-echo $0 | grep '/' || Work_Path_J=1
-if [ "$Work_Path_J" == "0"  ]; then
-    Work_Path=$(echo $0 | sed 's/install//')
-fi
-
-# Source functions
-if [ -f $Work_Path/install_func.sh ];then 
-  source $Work_Path/install_func.sh;
+if [ -f $Work_Path/install_func.sh ];then
+  Work_Path=`cd "$Work_Path"; pwd`
 elif [ -f $Work_Path/bin/install_func.sh ];then
-  source $Work_Path/bin/install_func.sh;
+  Work_Path=`cd "$Work_Path/bin"; pwd`;
 else
   echo "Import install-function-library error !!! ";
@@ -23,11 +15,15 @@
 fi
 
-if [ -f $Work_Path/lang_linl ];then 
+#Work_Path=./
+#Work_Path_J=0
+# Work Path setup
+#echo $0 | grep '/' || Work_Path_J=1
+#if [ "$Work_Path_J" == "0"  ]; then
+#    Work_Path=$(echo $0 | sed 's/install//')
+#fi
+
+# Source functions
+  source $Work_Path/install_func.sh;
   source $Work_Path/lang_link;
-elif [ -f $Work_Path/bin/lang_link ];then
-  source $Work_Path/bin/lang_link;
-else
-  echo "Import Language-File error !!! ";
-fi
 ### real code #####
 
@@ -76,5 +72,5 @@
     
     # 系統路徑鍊結
-    ln -sf /home/nutchuser/nutchez/system/nutchez /usr/local/sbin/nutchez
+    ln -sf /home/nutchuser/nutchez/system/nutchez /usr/local/bin/nutchez
 
     make_client_install
Index: /nutchez-0.2/src/shell/master_remove.sh
===================================================================
--- /nutchez-0.2/src/shell/master_remove.sh	(revision 223)
+++ /nutchez-0.2/src/shell/master_remove.sh	(revision 224)
@@ -68,5 +68,5 @@
 # 移除檔案及資料夾
 function remove_folders () {
-  rm /usr/local/sbin/nutchez
+  rm /usr/local/bin/nutchez
   show_info "$MR_remove_folders_echo_1" # "正在刪除安裝時所建立的檔案及資料夾..."
   rm -rf /opt/nutchez
Index: /nutchez-0.2/src/shell/nutchez
===================================================================
--- /nutchez-0.2/src/shell/nutchez	(revision 223)
+++ /nutchez-0.2/src/shell/nutchez	(revision 224)
@@ -18,5 +18,5 @@
 Tomcat_HOME="/opt/nutchez/tomcat"
 NutchEZ_HOME="/home/nutchuser/nutchez"
-Work_Path=
+Work_Path=$NutchEZ_HOME/system
 
 #Work_Path="./"

Index: /nutchez-0.2/src/shell/install_func.sh
===================================================================
--- /nutchez-0.2/src/shell/install_func.sh	(revision 223)
+++ /nutchez-0.2/src/shell/install_func.sh	(revision 224)
@@ -1,4 +1,3 @@
 #!/bin/bash
-#source $Work_Path/lang_link
 
 # shell檔及壓縮檔在同一目錄中
@@ -10,5 +9,6 @@
 Index_DB=$User_HOME/search
 Admin_email=nutchuser@nutch
-Start_PATH=`pwd`
+# Work_Path=(define on install)
+Install_Dir=$Work_Path/../
 MasterIP_Address=`/sbin/ifconfig eth0 | grep 'inet addr' |  sed 's/^.*addr://g' | sed 's/Bcast.*$//g' | sed 's/ .*// '` 
 net_MacAddr=`/sbin/ifconfig eth0 | grep 'HW' | sed 's/^.*HWaddr //g'`
@@ -85,10 +85,9 @@
 function unzip_nV2_pack(){
   local pac_name=nutchez-0.2pack-current.tar.gz
-  local svn_ver=218
-  if [ ! -d "./package" ];then
+  if [ ! -d "$Install_Dir/package" ];then
     mkdir ./package
   fi
-  if [ ! -e "./package/$pac_name" ];then
-    wget "http://trac.nchc.org.tw/cloud/export/$svn_ver/nutchez-0.2/src/package/$pac_name";
+  if [ ! -e "$Install_Dir/package/$pac_name" ];then
+    wget "http://nutchez.googlecode.com/files/$pac_name";
     if [ $? -eq 0 ];then
 	mv $pac_name ./package;
@@ -99,5 +98,5 @@
     fi
   fi
-  tar -zxvf ./package/$pac_name -C /opt/
+  tar -zxvf $Install_Dir/package/$pac_name -C /opt/
 }
 
@@ -416,5 +415,5 @@
 
 function client_PassMasterIPAddr () {
-  cd $Start_PATH
+  cd $Work_Path
   Line_NO=`cat client_install | grep -n '# Master IP here' | sed 's/:.*//g'`
   debug_info "$MI_client_PassMasterIPAddr_echo_1"
@@ -430,5 +429,5 @@
 
 function client_PassMaster_Hostname () {
-  cd $Start_PATH
+  cd $Work_Path
   Line_NO=`cat client_install | grep -n '# Master Hostname here' | sed 's/:.*//g'`
   debug_info "$MI_client_PassMaster_Hostname_echo_1"
@@ -443,5 +442,5 @@
 
 function client_PassMasterIPAddr_for_Remove () {
-  cd $Start_PATH
+  cd $Work_Path
   Line_NO=`cat client_remove.sh | grep -n "# Master IP here" | sed 's/:.*//g'`
   sed -i ''$((Line_NO+1))'d' client_remove.sh
@@ -468,12 +467,17 @@
   # 複製檔案至$User_HOME/source目錄下
   mv NutchezForClientOf_$MasterIP_Address.tar.gz /home/nutchuser/nutchez/source
-  cp $Start_PATH/client_install $Start_PATH/client_install_func.sh $Start_PATH/client_remove.sh $Start_PATH/lang_link  /home/nutchuser/nutchez/source
-  cp -r $Start_PATH/lang /home/nutchuser/nutchez/source
-  cp -r $Start_PATH/lang /home/nutchuser/nutchez/system
-  cp $Start_PATH/nutchez $Start_PATH/lang_link $Start_PATH/add_hosts $Start_PATH/duplicate_del $Start_PATH/master_remove.sh /home/nutchuser/nutchez/system
-
-#  cp $Start_PATH/client_install $Start_PATH/client_install /home/nutchuser/nutchez/source
-#  cp $Start_PATH/client_install $Start_PATH/client_remove.sh /home/nutchuser/nutchez/source
-#  cp $Start_PATH/client_install $Start_PATH/lang* /home/nutchuser/nutchez/source
+  cp $Work_Path/client_install $Work_Path/client_install_func.sh $Work_Path/client_remove.sh $Work_Path/lang_link  /home/nutchuser/nutchez/source
+  cp -r $Work_Path/lang /home/nutchuser/nutchez/source
+  cp -r $Work_Path/lang /home/nutchuser/nutchez/system
+  cp $Work_Path/nutchez $Work_Path/lang_link $Work_Path/add_hosts $Work_Path/duplicate_del $Work_Path/master_remove.sh /home/nutchuser/nutchez/system
+  
+  # 複製 nutchez/source 到使用者的安裝資料夾
+   
+   mkdir $Install_Dir/Client_DIR
+   cp -rf /home/nutchuser/nutchez/source/* $Install_Dir/Client_DIR/
+   
+#  cp $Work_Path/client_install $Work_Path/client_install /home/nutchuser/nutchez/source
+#  cp $Work_Path/client_install $Work_Path/client_remove.sh /home/nutchuser/nutchez/source
+#  cp $Work_Path/client_install $Work_Path/lang* /home/nutchuser/nutchez/source
 }
 